@@ -2,13 +2,17 @@ import pygtk; pygtk.require("2.0")
 import gtk
 import gconf
 import gnome.ui
-import gnome.vfs
+try:
+	import gnomevfs
+except:
+	import gnome.vfs as gnomevfs
+
 
 GNOME_APP_ID = "gtstarter"
 SCRIPT_VERSION = "0.4.6"
 SCRIPT_NAME = "GTStarter"
 
-SCRIPT_COPYRIGHT = "(c) 2004 Franz Klammer"
+SCRIPT_COPYRIGHT = "(c) 2005 Franz Klammer"
 SCRIPT_DESCR = "Start the gnome-terminal from a list of configured profiles"
 SCRIPT_AUTHORS = ["Franz Klammer <klammer@webonaut.com>"]
 SCRIPT_DOCU = []
@@ -34,6 +38,37 @@ TODO (or not todo):
 	* translation?
 """
 
+ui_string = """<ui>
+  <menubar name='Menubar'>
+    <menu action='FileMenu'>
+      <menuitem action='Quit'/>
+    </menu>
+    <menu action='ViewMenu'>
+      <menuitem action='Refresh'/>
+      <separator/>
+      <menuitem action='HideToolBar'/>
+    </menu>
+    <menu action='SettingsMenu'>
+      <menuitem action='dblClick'/>
+      <menuitem action='keepOpen'/>
+      <menuitem action='remWinSize'/>
+      <separator/>
+      <menu action='remWinPosMenu'>
+        <menuitem action='centerWindow'/>
+        <menuitem action='remWinPos'/>
+        <menuitem action='noDefWinPos'/>
+      </menu>
+    </menu>
+    <menu action='helpMenu'>
+      <menuitem action='helpAbout'/>
+    </menu>
+  </menubar>
+  <toolbar name='Toolbar'>
+    <toolitem action='Quit'/>
+    <toolitem action='Refresh'/>
+  </toolbar>
+</ui>"""
+
 class gt_starter(gnome.ui.App):
 	
 	def __init__(self):
@@ -65,6 +100,8 @@ class gt_starter(gnome.ui.App):
 		self.__winpos_x = 0
 		self.__winpos_y = 0
 
+		self.__iconlist = None
+
 		self.__window_is_there = False	
 
 		
@@ -96,8 +133,10 @@ class gt_starter(gnome.ui.App):
 	def __load_config(self):
 		self.__start_double_click = self.__gconf_client.get_bool(self.__my_conf_path+"/double_click")
 		self.__double_click_menu_item.set_active(self.__start_double_click)
+
 		self.__keep_open = self.__gconf_client.get_bool(self.__my_conf_path+"/keep_open")
 		self.__keep_open_menu_item.set_active(self.__keep_open)
+
 		self.__remember_wsize = self.__gconf_client.get_bool(self.__my_conf_path+"/remember_wsize")
 		self.__remember_wsize_menu_item.set_active(self.__remember_wsize)
 
@@ -124,33 +163,34 @@ class gt_starter(gnome.ui.App):
 		self.__hide_toolbar_menu_item.set_active(self.__hide_toolbar)
 
 			
-	def __set_click_behaviour(self, menu_nr, menu_item_obj):
-		self.__start_double_click = menu_item_obj.active
+	def __set_click_behaviour(self, gtk_action_obj):
+		self.__start_double_click = gtk_action_obj.get_active()
 		self.__gconf_client.set_bool(self.__my_conf_path+"/double_click", self.__start_double_click)
 
 
-	def __set_quit_behaviour(self, menu_nr, menu_item_obj):
-		self.__keep_open = menu_item_obj.active
+	def __set_quit_behaviour(self, gtk_action_obj):
+		self.__keep_open = gtk_action_obj.get_active()
 		self.__gconf_client.set_bool(self.__my_conf_path+"/keep_open", self.__keep_open)
 				
 		
-	def __set_rem_wsize(self, menu_nr, menu_item_obj):
-		self.__remember_wsize = menu_item_obj.active
+	def __set_rem_wsize(self, gtk_action_obj):
+		self.__remember_wsize = gtk_action_obj.get_active()
 		self.__gconf_client.set_bool(self.__my_conf_path+"/remember_wsize", self.__remember_wsize)
 		self.__get_window_size_pos()
 		
 
-	def __set_hide_toolbar(self, menu_nr, menu_item_obj):
-		self.__hide_toolbar = menu_item_obj.active
+	def __set_hide_toolbar(self, gtk_action_obj):
+		print dir(gtk_action_obj)
+		print gtk_action_obj.get_active()
+		self.__hide_toolbar = gtk_action_obj.get_active()
 		self.__gconf_client.set_bool(self.__my_conf_path+"/hide_toolbar", self.__hide_toolbar)
 		self.__toggle_toolbar()
 
 
-	def __set_window_position(self, menu_nr, menu_item_obj):
-		if menu_item_obj.active:
-			self.__win_startup_pos = menu_nr
-			self.__gconf_client.set_int(self.__my_conf_path+"/window_startup_position", self.__win_startup_pos)
-			self.__get_window_size_pos()
+	def __set_window_position(self, gtk_action_obj, gtk_radion_action_obj):
+		self.__win_startup_pos = gtk_radion_action_obj.get_current_value()
+		self.__gconf_client.set_int(self.__my_conf_path+"/window_startup_position", self.__win_startup_pos)
+		self.__get_window_size_pos()
 
 
 	def dummy(self, *argv):
@@ -164,89 +204,85 @@ class gt_starter(gnome.ui.App):
 			self.get_dock_item_by_name("Toolbar").show()
 
 
-		
-	def __get_menubar(self):
-		menu_items = (
-			( "/_File",				None, None, 				0, "<Branch>" ),
-			( "/File/_Quit",			None, self.__quit_gtstarter,		0, "<StockItem>", gtk.STOCK_QUIT ),
-			( "/_View",				None, None, 				0, "<Branch>"),
-			( "/View/_Refresh", 			None, self.__build_iconlist,		0, "<StockItem>", gtk.STOCK_REFRESH),
-			( "/View/sep1",				None, None,				0, "<Separator>" ),
-			( "/View/ hide toolbar",		None, self.__set_hide_toolbar,		0, "<ToggleItem>"),
-			( "/_Settings",				None, None, 				0, "<Branch>" ),
-			( "/Settings/ double click",		None, self.__set_click_behaviour,	0, "<ToggleItem>"),
-			( "/Settings/ keep open",		None, self.__set_quit_behaviour,	0, "<ToggleItem>"),
-			( "/Settings/sep1",			None, None,      			0, "<Separator>" ),
-			( "/Settings/ remember window size",	None, self.__set_rem_wsize,		0, "<ToggleItem>"),
-			( "/Settings/ window position/ center window",			None, self.__set_window_position,	0, "<RadioItem>" ),
-			( "/Settings/ window position/ remember window position",	None, self.__set_window_position,	1, "/Settings/ window position/ center window" ),
-			( "/Settings/ window position/ no default window postition",	None, self.__set_window_position,	2, "/Settings/ window position/ center window" ),
-			#TODO: really add this? 
-			#( "/Settings/sep2",			None, None,      			0, "<Separator>" ),
-			#( "/Settings/ edit startup paths",		None, self.dummy,	0, "<StockItem>", gtk.STOCK_PROPERTIES),
-			( "/_Help",				None, None, 				0, "<LastBranch>" ),
-			( "/Help/_About",			None, self.show_about, 		0, "<StockItem>", "gnome-stock-about"),
-			)
+	def __create_menu_and_toolbar(self):
+		ag = gtk.ActionGroup('WindowActions')
+		my_actions = [
+			('FileMenu', None, 		'_File'),
+			( "Quit",    gtk.STOCK_QUIT,	'_Quit', '<control>Q', 'Quit application', self.__quit_gtstarter ),
 
+			('ViewMenu', None, '_View'),
+			( "Refresh",	gtk.STOCK_REFRESH,	'_Refresh',	 '<control>R', 'Refresh', self.__build_iconlist ),
 
-		accel_group = gtk.AccelGroup()
-		item_factory = gtk.ItemFactory(gtk.MenuBar, "<main>", accel_group)
+			('SettingsMenu', None, '_Settings'),
+			('remWinPosMenu', None, 'window position'),
+			('helpMenu', None, '_Help'),
+			( "helpAbout",	gtk.STOCK_ABOUT,	'_About',	 None, None, self.show_about )
+			]
+		my_toggle_actions = [
+			( "remWinSize",  None,			'remember window size', None,        None,      self.__set_rem_wsize, False),
+			( "HideToolBar", None,			'hide toolbar',   None,        None,      self.__set_hide_toolbar, False),
+			( "dblClick",    None,			'_double click',  None,        None,      self.__set_click_behaviour, False),
+			( "keepOpen",    None,			'_keep open',     None,        None,      self.__set_quit_behaviour, False)
+			]
 
-		item_factory.create_items(menu_items)
+		my_radio_actions = [
+			('centerWindow', None, 'center window', None, None, 0),
+			('remWinPos', None, 'remember window position', None, None, 1),
+			('noDefWinPos', None, ' no default window postition', None, None, 2)
+			]
 
-		self.__double_click_menu_item = item_factory.get_item("/Settings/ double click")
-		self.__keep_open_menu_item = item_factory.get_item("/Settings/ keep open")
-		self.__remember_wsize_menu_item = item_factory.get_item("/Settings/ remember window size")
+		ag.add_actions(my_actions)
+		ag.add_toggle_actions(my_toggle_actions)
+		ag.add_radio_actions(my_radio_actions, 0, self.__set_window_position)
+		self.ui.insert_action_group(ag, 0)
+		self.add_accel_group(self.ui.get_accel_group())
+
+		menu = self.ui.get_widget('/Menubar')
+		self.set_menus(menu)
+
+		self.__toolbar = self.ui.get_widget('/Toolbar')
+		self.set_toolbar(self.__toolbar)
+
+		self.__double_click_menu_item = self.ui.get_action("ui/Menubar/SettingsMenu/dblClick")
+		self.__keep_open_menu_item = self.ui.get_action("ui/Menubar/SettingsMenu/keepOpen")
+		self.__remember_wsize_menu_item = self.ui.get_action("ui/Menubar/SettingsMenu/remWinSize")
 		self.__win_startup_pos_menu_item = []
-		self.__win_startup_pos_menu_item.append(item_factory.get_item("/Settings/ window position/ center window"))
-		self.__win_startup_pos_menu_item.append(item_factory.get_item("/Settings/ window position/ remember window position"))
-		self.__win_startup_pos_menu_item.append(item_factory.get_item("/Settings/ window position/ no default window postition"))
+		self.__win_startup_pos_menu_item.append(self.ui.get_action("ui/Menubar/SettingsMenu/remWinPosMenu/centerWindow"))
+		self.__win_startup_pos_menu_item.append(self.ui.get_action("ui/Menubar/SettingsMenu/remWinPosMenu/remWinPos"))
+		self.__win_startup_pos_menu_item.append(self.ui.get_action("ui/Menubar/SettingsMenu/remWinPosMenu/noDefWinPos"))
 
-		self.__hide_toolbar_menu_item = item_factory.get_item("/View/ hide toolbar")
-		
-		self.add_accel_group(accel_group)
-		menu = item_factory.get_widget("<main>")
-		menu.show()
-
-		return menu
-
-
-	def __get_toolbar(self):
-		toolbar = gtk.Toolbar()
-		toolbar.show()
-		tb1 = toolbar.insert_stock(gtk.STOCK_QUIT, "Quit", "", self.__quit_gtstarter, 0, -1)
-		tb2 = toolbar.insert_stock(gtk.STOCK_REFRESH, "Refresh", "", self.__rebuild_iconlist, 0, -1)
-		return toolbar
+		self.__hide_toolbar_menu_item = self.ui.get_action("ui/Menubar/ViewMenu/HideToolBar")
 
 
 	def __build_gui(self):
 		gnome.program_init(GNOME_APP_ID, SCRIPT_VERSION)
 		gnome.ui.App.__init__(self, GNOME_APP_ID, SCRIPT_NAME)
 
-		self.set_menus(self.__get_menubar())
-		self.__toolbar = self.__get_toolbar()
-		self.set_toolbar(self.__toolbar)
+		self.ui = gtk.UIManager()
+		self.ui.add_ui_from_string(ui_string)
+
+		self.__create_menu_and_toolbar()
 
 		self.connect('destroy', self.__quit_gtstarter)
 
 		self.set_icon(gtk.gdk.pixbuf_new_from_file(GTS_ICON))
 		self.__statusbar = gtk.Statusbar()
-		self.__statusbar.set_has_resize_grip(gtk.TRUE)
+		self.__statusbar.set_has_resize_grip(True)
 		self.__statusbar.show()
 		self.set_statusbar(self.__statusbar)
 
-		self.__iconlist_adjustment = gtk.Adjustment()
-		self.__iconlist = gnome.ui.IconList(100, self.__iconlist_adjustment, 0)
+		self.__scrolledwin = gtk.ScrolledWindow()
+		self.__scrolledwin.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
+
+		__iconlist_adjustment = gtk.Adjustment()
+		self.__iconlist = gnome.ui.IconList(100, __iconlist_adjustment, 0)
 		self.__iconlist.connect("select_icon", self.__select_handler)
 		self.__iconlist.connect("motion-notify-event", self.__mouse_motion_handler)
 		self.__iconlist.show()
-		
 		self.__build_iconlist()
-		
-		self.__scrolledwin = gtk.ScrolledWindow()
-		self.__scrolledwin.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
-		self.__scrolledwin.show()
+
 		self.__scrolledwin.add(self.__iconlist)
+		self.__scrolledwin.show()
 
 		self.set_contents(self.__scrolledwin)
 		
@@ -271,7 +307,7 @@ class gt_starter(gnome.ui.App):
 
 		self.__load_profile_data()
 		self.__iconlist.clear()
-		
+
 		for profile_name in self.__profile_list:
 			profile_icon_name, visible_name = self.__get_data_from_profile(profile_name)
 			profile_icon = gtk.gdk.pixbuf_new_from_file(profile_icon_name)
@@ -374,7 +410,7 @@ class gt_starter(gnome.ui.App):
 	def __start_with_window(self, menu_item = None):
 		profile_icon_name, visible_name = self.__get_data_from_profile(self.__profile_list[self.__active_profile])
 
-		#workURI = gnome.vfs.URI("file:///home/klammer/Desktop/screen2/%3F%3F%3F%3F%3F")
+		#workURI = gnomevfs.URI("file:///home/klammer/Desktop/screen2/%3F%3F%3F%3F%3F")
 		#print workURI.path
 		#cmd = "gnome-terminal --window-with-profile=\"" + visible_name + "\" --working-directory="+workURI.path
 
@@ -469,7 +505,7 @@ class gt_starter(gnome.ui.App):
 	def gtstarter_run(self):
 		self.__build_gui()
 		
-	def show_about(self, menu_nr, menu_item_obj):
+	def show_about(self, gtk_action_obj):
 		pixbuf = gtk.gdk.pixbuf_new_from_file(GTS_ABOUT_PIX)
 		gnome_about = gnome.ui.About(SCRIPT_NAME, SCRIPT_VERSION, SCRIPT_COPYRIGHT,
 						SCRIPT_DESCR, SCRIPT_AUTHORS, SCRIPT_DOCU, SCRIPT_TRANS, pixbuf)
